@@ -2,7 +2,7 @@ package PDF::Reuse::Tutorial;
 
 use strict;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 1;
 
@@ -101,8 +101,7 @@ run the programs, so it might be a good idea to extract the programs to that
 directory. Also unzip the files from unzipThis.zip to the same directory. 
 
 The program only works when you have prepared the pod with '=for name begin' and
-'=for end', and that has been done with this module, B<PDF::Reuse::Scramble> and
-B<PDF::Reuse::SimpleChart>.
+'=for end', and that has been done with this module, and B<PDF::Reuse::SimpleChart>.
 
 =head1 Ordinary tasks
 
@@ -723,7 +722,6 @@ prDoc() like this:
     prText(100, 500, 'This is put on the first page');
     prPage();
     prDoc('doc/piped.pdf');
-    prPage();
     prForm('ex1.pdf');
     prText(100, 500, 'This is put on the last page');
 
@@ -812,295 +810,6 @@ be scaled independently.
 
 =for end
 
-=head2 Defining interactive fields programmatically
-
-The "normal" way to define interactive fields, is to use Acrobat as a screen
-painter. You draw your fields, write your JavaScript, or cut and paste, and so
-on. It is convenient for single files, but if you are going to produce thousands
-of files, which are not going to look exactly the same, it is not very practical.
-I guarantee you get tired very quickly.
-
-Then it is better to do the job programmatically. Here is an example:
-
-You need an Acrobat JavaScript which defines some fields. It can look like
-this (script1.js):
-
-=for script1.js begin
-
-   function nameAddress(page, xpos, ypos)
-   {  var thePage = 0;
-      if (page)
-      {   thePage = page;
-      }
-      var myRec = [ 40, 650, 0, 0];              // default position
-      if (xpos)
-      {   myRec[0] = xpos;
-      }
-      if (ypos)
-      {   myRec[1] = ypos;
-      }
-	
-      var labelText = [ "Mr/Ms", "First_Name", "Surname",
-                        "Adress", "City", "Zip_Code", "Country",
-                        "Phone", "Mobile_Phone", "E-mail",
-                        "Company", "Profession", "Interest_1", "Interest_2",
-                        "Hobby" ];   
-   
-      for ( var i = 0; i < labelText.length; i++)
-      {   myRec[2] = myRec[0] + 80;               // length of the label
-          myRec[3] = myRec[1] - 15;               // height ( or depth if you like)
-
-          // a label field is created
-
-          var fieldName = labelText[i] + "Label";
-          var lf1       = this.addField(fieldName, "text", thePage, myRec);
-          lf1.fillColor = color.white;
-          lf1.textColor = color.black;
-          lf1.readonly  = true;
-          lf1.textSize  = 12;
-          lf1.value     = labelText[i];
-          lf1.display   = display.visible;
-
-          // a text field for the customer to fill-in his/her name is created   
- 
-          myRec[0] = myRec[2] + 2;               // move 2 pixels to the right 
-          myRec[2] = myRec[0] + 140;             // length of the fill-in field
-
-          var tf1         = this.addField(labelText[i], "text", thePage, myRec);
-          tf1.fillColor   = ["RGB", 1, 1, 0.94];
-          tf1.strokeColor = ["RGB", 0.7, 0.7, 0.6];
-          tf1.textColor   = color.black;
-          tf1.borderStyle = border.s;
-          tf1.textSize    = 12;
-          tf1.display     = display.visible;
-      
-          myRec[0] = myRec[0] - 82    // move 82 pixels to the left
-          myRec[1] = myRec[1] - 17;   // move 17 pixels down
-      } 
-         
-   }
-
-=for end
-
-A little program that uses the script could look like this:
-
-=for interactive1.pl begin
-
-   use PDF::Reuse;
-
-   prDocDir('doc');
-   prFile('Ex15.pdf');
-   prCompress(1);                   # To compress new JavaScripts
-   prJs('script1.js');              # To include the JavaScript
-   prInit('nameAddress();');        # To call nameAddress(); at start up
-   prEnd();
-
-=for end
-
-Within the parenthesis of prInit(), you can put JavaScript code to be executed when
-the PDF-file is opened. But there is an important limitation you should be aware of.
-When the file is opened the JavaScript interpreter I<is working>, but it is B<only 
-partially aware of old JavaScripts or interactive fields already defined.> That's
-why all functions you refer to within prInit(), should have been included with prJs()
-first. The JavaScript interpreter has simply not read the document, when the
-initiation is done.
-
-B<Mind the warning under JavaScript in the beginning of this document.> 
-
-=head2 Initiate interactive fields
-
-In PDF::Reuse there is one function that assigns values to interactive fields. It is
-prField($fieldName, $fieldValue). It works also for old interactive fields in the file.
-(I don't know why.) When you use this function, you have to spell the fieldname exactly as it is done in
-PDF-file. The spelling is case-sensitive.(And please, avoid initial spaces in names, 
-when you define new fields.)
-
-We add values to a few fields in the previous file:
-
-=for prField.pl begin
-
-   use PDF::Reuse;
-
-   prDocDir('doc');
-   prFile('Ex16.pdf');
-   prJs('script1.js');              # To include the JavaScript
-   prInit('nameAddress();');
-   prField('First_Name', 'Lars');
-   prField('Surname', 'Lundberg');
-   prField('City', 'Stockholm');
-   prField('Country', 'Sweden');       
-   prEnd();
-
-=for end
-
-This example uses JavaScript, so remember the general warning.
-
-=head2 A variant of previous example
-
-You could had written the previous example like this also (if you saved the 
-file Ex16.pdf after the fields had been created):
-
-=for prDocForm.pl begin
-
-   use PDF::Reuse;
-   prDocDir('doc');
-   prFile('Ex17.pdf');
-   prField('First_Name', 'Lars');
-   prField('Surname', 'Lundberg');
-   prField('City', 'Stockholm');
-   prField('Country', 'Sweden');
-   prDocForm('doc/Ex16.pdf');
-   prEnd();
-
-=for end 
-
-The prDocForm(), works like prForm() but also takes interactive fields and
-JavaScripts with it. If you would have used prForm() here, you would only have received
-an empty page. That might be a little confusing, but the graphic elements and the
-interactive ones, follow two different logical lines. It can be difficult to see what
-is graphic and what is interactive, if you haven't got Acrobat. 
-
-You should put all your PrField, prJs and prInit before the first prDocForm or prDoc,
-because all JavaScripts and interactive fields are merged when the program starts
-to analyze the first interactive page it is going to include. If you have many calls
-to prDoc or prDocForm in your program, only the first one will bring JavaScripts and
-interactive functions with it, the rest of the times only graphic elements within
-the pages are taken. Perhaps I should try to solve these problems in a future
-version of PDF::Reuse.  
-
-=head2 A popup menu with common links
-
-You have some PDF-files on your web site, and now you want to add a standard popup 
-menu with links to your documents.
-
-To accomplish this, we create 2 JavaScrips.
-
-The first JavaScript, "Button.js", consists of 3 functions. "Sensitive" defines an
-area. If you move your mouse into it, you get a tool tip text, and if you click within
-it you trigger an action. "get" fetches something over the net. "But" creates a
-visible button.
-
-=for Button.js begin
-
-    function Sensitive(page, x, upperY, length, depth, action, toolTip)
-    {  var myRec = [ 400, 50, 100, 12];
-	    if (x)
-	    {  myRec[0] = x;
-	    }
-	    if (upperY)
-	    { myRec[1] = upperY;
-	    }
-   
-       if (length)
-       {  myRec[2] = myRec[0] + length;
-       }
-       if (depth)
-       {  myRec[3] = myRec[1] - depth;
-       }
-
-       var fName = 'p' + page + 'x' + x + 'y' + upperY; 
-       var f = this.addField(fName,"button", page , myRec);
-       if (action)
-       {   f.setAction("MouseUp", action);
-       }
-       if (toolTip)
-       {   f.userName = toolTip;
-       }
-    }
-    function get(target)
-    {  this.getURL(target, false);
-    } 
- 
-    function But(page, x, upperY, length, depth, action, toolTip, cap)
-    {  var myRec = [ 400, 50, 100, 12];
-	    if (x)
-	    {  myRec[0] = x;
-	    }
-	    if (upperY)
-	    { myRec[1] = upperY;
-	    }
-   
-       if (length)
-       {  myRec[2] = myRec[0] + length;
-       }
-       if (depth)
-       {  myRec[3] = myRec[1] - depth;
-       }
-       var fName = 'p' + page + 'x' + x + 'y' + upperY; 
-       var f = this.addField(fName,"button", page , myRec);
-       if (action)
-       {   f.setAction("MouseUp", action);
-       }
-       if (toolTip)
-       {   f.userName = toolTip;
-       }
-       f.buttonSetCaption(cap);
-       f.display     = display.noPrint;
-       f.borderStyle = border.i;
-       f.fillColor   = ["RGB", 0.6, 0.6, 0.95];
-    }
-
-=for end
-
-The standard popup menu is defined in "popUp.js".
-
-=for popUp.js begin
-
-    function popUp()
-    {   var b = 'http://127.0.0.1:80/';
-        var a = ['cgi-bin/OffertNy.pl', 'EUSA.pdf', 'sign_HER.pdf', 
-                 'lastYear.pdf', 'best2.pdf', 'bild.pdf', 
-                 'Btrees.pdf', 'Calculator.pdf', 'Check.pdf', 
-                 'Eastern.pdf', 'fel.pdf'];
-        var n = ['Overview', 'Map', 'Base Values', 
-                 'Last year', 'Something', 'Picture', 
-                 'Ordered', 'Calculator', 'Check values',
-                 'Other map', 'Totally'];
-        var c = app.popUpMenu(['General', n[0], n[1], n[2]], 
-                ['Historical', n[3], n[4], '-', n[9], n[10]], 
-                ['Impacts', n[5], n[6], n[7], '-', n[8]] );
-        var i;
-        for (i = 0; i < n.length; i++)
-        {   if (c == n[i])
-            {   var target = b + a[i];
-                get(target);
-                break;
-            }
-        }
-    }
-
-=for end 
-
-A few explanations: "b" is the base URL. "a" is an array of actions/documents.
-"n" is an array of names of the actions/documents. "a" and "n" should have same
-number of elements. "c" is the choice. If you have made a choice, the program
-finds out what action corresponds to it.
-
-We create a new document from LetterB.pdf and put a button for the popup menu
-in the lower right corner.
-
-=for popUp1.pl begin
-
-     use PDF::Reuse;
-     use strict;
-
-     prFile('doc/popup1.pdf');
-     
-     prJs('Button.js');            # First JavaScript is included
-
-     prJs('popUp.js');             # Second JavaScript is included
-
-     my $jsCode = 'But(0, 450, 200, 100, 30,"popUp();",
-                   "Links to related documents", "Other documents >");';
-
-     prInit($jsCode);              # At initiation a button is defined via 
-                                   # But(), and it's action will be popUp()
-
-     prDoc('LetterB.pdf');
-     prEnd();
-
-=for end
-
 =head2 Merging paper, bookmarks and the web   
 
 Bookmarks can help you to navigate better within a document, this is what they are
@@ -1242,171 +951,6 @@ from PDF::Reuse::Util, or you can use prLink for more detail control.
 
 =for end
 
-=head2 Filling in a form without spending a fortune
-
-If you want to fill in a form over the net, the simplest way is just to use HTML.
-That is cheap and straightforward. If you want to use a PDF-form, you will 
-get new expenses. All your users will need something better and more expensive
-than the Reader, or they will need a plug in, or you will have to invest in
-server programs which can extend the rights of the PDF-documents.
-Anyway, in all these cases there is a price tag, and it can be substantial.
-
-Another simple alternative could be to send data from a PDF-document back to the
-server with the help of JavaScript and a getURL-sentence. (Data is not yet encrypted,
-and the user can't save the form, and there are also other shortcomings, so still
-there might be reasons for heavy investments.)
-
-Here is an example of a newsletter which can be sent by mail. At the end of the
-document there are some fields with name and address and a button to unsubscribe.
-
-You have produced a newsletter from a web page e.g. with HTMLDOC or Web Capture
-from Acrobat. Let's call it "newsTemplate.pdf". It is 4 pages. We create a little
-program which takes this document and adds a page with a simple fill-in form. First
-we need a JavaScript which defines the fields, and then we need another one which 
-collects data from the fields, creates and URL-encodes the query string and at last 
-sends the request.
-The file with JavaScript functions could look a little like this 
-("fillIn.js")
-
-=for fillIn.js begin
-   
-   function fieldsAndButtons(page, x, y)   
-   {  var l;     
-      var d;
-      var labelText = [ "Mr_Ms", "First_Name", "Surname",
-                        "Address", "City", "Zip_Code", "Country",
-                        "Phone", "Mobile_Phone", "E-mail",
-                        "Company", "Interest_1", "Interest_2",
-                        "Interest_3" ];   
-   
-      for ( var i = 0; i < labelText.length; i++)
-      {   l = x + 80;               // length of the label
-          d = y - 15;               // depth / hight 
-
-          // a label field is created
-
-          var fieldName = labelText[i] + "Label";
-          var lf1       = this.addField(fieldName, "text", page, [x,y,l,d]);
-          lf1.fillColor = color.white;
-          lf1.textColor = color.black;
-          lf1.readonly  = true;
-          lf1.textSize  = 12;
-          lf1.defaultValue = labelText[i];
-          lf1.value     = labelText[i];
-          lf1.display   = display.visible;
-
-          // a text field for the customer to fill-in his/her data is created   
- 
-          x = l + 2;               // move 2 pixels to the right 
-          l = x + 140;             // length of the fill-in field
-
-          var tf1         = this.addField(labelText[i], "text", page, [x,y,l,d]);
-          tf1.fillColor   = ["RGB", 1, 1, 0.94];
-          tf1.strokeColor = ["RGB", 0.7, 0.7, 0.6];
-          tf1.textColor   = color.black;
-          tf1.borderStyle = border.s;
-          tf1.textSize    = 12;
-          tf1.display     = display.visible;
-      
-          x = x - 82    // move 82 pixels to the left
-          y = y - 17;   // move 17 pixels down
-      }
-      y = y + 34;
-      x = x + 250;
-      l = x + 75;
-      d = y - 30;
-      var f = this.addField("ButUpdate","button", page , [x,y,l,d]);
-      f.setAction("MouseUp", "sendUpdates()");
-      f.userName = "Press here to send updated data from this form";
-      f.buttonSetCaption("Update");
-      f.borderStyle = border.b;
-      f.fillColor   = ["RGB", 0.6, 0.6, 0.95];
-      y = y - 60;
-      d = y - 30;
-      var f = this.addField("ButUnsubscribe","button", page , [x,y,l,d]);
-      f.setAction("MouseUp", "unSubscribe()");
-      f.userName = "Press here to unsubscribe to the newsletter";
-      f.buttonSetCaption("Unsubscribe");
-      f.borderStyle = border.b;
-      f.fillColor   = ["RGB", 0.95, 0.9, 0.9];             
-   }
-
-   function unSubscribe()
-   {  var dest = 'http://127.0.0.1:80/cgi-bin/unsubscr.pl?cust=' + getCust() + '&nl'; 
-      this.getURL(dest, false);
-   }
-   function sendUpdates()
-   {  var str = '';
-      for (var i = 0; i < this.numFields; i++)
-      {   var theName = this.getNthFieldName(i);
-          var f = this.getField(theName);
-          if ((f.type == 'text') && (f.defaultValue != f.value)) 
-          {   str = str + theName + '=' + hexEncode(f.value) + '&';
-          }
-      }
-      var dest = 'http://127.0.0.1:80/cgi-bin/update.pl?cust=' + getCust() + '&' + str; 
-      this.getURL(dest, false);
-   }
-   function hexEncode(str)
-   {   var out = '';
-       for (var i = 0; i < str.length; i++)
-       {  var num = str.charCodeAt(i);
-          if ((num < 48) || (num > 122) || ((num > 57) && (num < 65))
-          || ((num > 90) && (num < 97))) 
-             out = out + '%' + util.printf("%x", num);
-          else
-             out = out + str[i];
-       }
-       return out;  
-   }
-
-=for end
-
-The Perl program that produces the newsletter could look like this
-
-=for newsLetter.pl begin
-
-     use PDF::Reuse;
-     use Mail::Sender;
-     use strict;
-    
-     my $now = localtime;
-
-     my $sender = new Mail::Sender {smtp => 'smtp.company.com', 
-                                    from => 'us@myJob.com'};
-
-     my @customers = (1, 2, 3, 4, 5);     # And lots of others
-     my %addresses = (1 => 'a@com', 
-                      2 => 'b@com',
-                      3 => 'c@com',
-                      4 => 'd@com',
-                      5 => 'e@com');      # and lots of others
- 
-     for my $cust (@customers)
-     {   if (! exists $addresses{$cust})
-         {  next;
-         }
-         prFile("news$cust.pdf");
-         prCompress(1);
-         prJs('fillIn.js');
-         prJs("function getCust() { return '$cust'; }");     
-         my $jsCode = "fieldsAndButtons(4, 100, 800);";
-         prInit($jsCode);
-         prDoc('newsTemplate.pdf');
-         prPage();
-         prText(10, 100, ' ');        
-         prEnd();
-         
-         $sender->MailFile(  {to      => $addresses{$cust},
-                              subject => "News, $now",
-                              msg     => 'Your newsletter',
-                              file    => "news$cust.pdf"} );        
-     }
-
-=for end
-
-If you use PDF::Reuse::Scramble, you can "encrypt" the messages sent back to
-the server, so you can be sure about who sent them.
 
 =head2 Simple charts
 
@@ -1939,53 +1483,6 @@ get an error log on the desktop.
 The first time you run via an ActiveX object, it is fairly slow, but if you
 do it repeatedly, the performance is quit acceptable.
 
-=head2 Checking version of the browser 
-
-One problem with JavaScript and Acrobat Reader is that prior to version 5.1 you couldn't
-create buttons or text fields dynamically. So we have to be prepared for that. 
-
-I have created a little PDF-file with a text and a button. If the user has an earlier
-version of Acrobat Reader or Acrobat, he will be asked to download the latest Acrobat
-Reader. If he has a workable version of the browser, the two fields will be hidden.
-You should have received 'downLink.pdf' in the distribution.
-I also hope that you received 'customerResponse.js'. With those files we can continue
-with the next program ('versionCheck.pl'):
-
-=for versionCheck.pl begin
-
-    use PDF::Reuse;
-
-    prDocDir('doc');
-    prLogDir('run');
-
-    prFile('ex18.pdf');
-
-    prJs('customerResponse.js');
-    prInit('nameAddress(0, 100, 700);');
-    prInit('butt(0, 400, 700);');
-    prField('First_Name', 'Lars');
-    prField('Surname', 'Lundberg');
-    prField('City', 'Stockholm');
-    prDocForm('downLink.pdf');
-    prFontSize(18);
-    prText(75, 770, 'Please, give us correct information about you !');
-    prEnd();
-
-=for end
-
-Here the user fills in some data about himself, and if he has Acrobat, he can sign
-it electronically and send it back by mail. The form data will be transferred
-as an FDF-file, which is fairly compact.
-If the user has Acrobat Reader he doesn't get any buttons to sign or return the data by 
-mail. He simply has to fill in the form, print it, sign it with a pencil and send the
-page by fax. (Adobe has server programs which can extend the "document rights" so
-you can sign and save documents also with the Reader. I haven't tested PDF::Reuse
-together with these programs, but if it could be used, the JavaScripts could be changed
-and the program would be much more useful.) 
-
-When the program is run, a log is produced. It will be approx. 2% of the formatted 
-file. 
-
 =head2 Generate OO-code
 
 You can generate graphic objects and subroutines from B<simple> PDF-files.
@@ -2254,145 +1751,14 @@ The ' is an operator that moves to the next line and shows the text string.
 
 When you run this program the PDF-file will be 53 kB.
 
-=head2 A variant of a popup menu
-
-You want to build a popup menu from a structure of hashes and arrays of hashes.
-Each hash can have these components
-     
-     text   
-     kids | act   a JavaScript action
-
-
-The structure could also be used to create bookmarks, but here it is a little more
-limited. Only hashes without kids can have actions. (It is perhaps easier to
-define bookmarks, but you feel that they are too closely connected to the
-structure of the document.) 
-There should have been a routine to handle passwords in this example, but we
-disregard that, not to complicate the code too much. Also there should a
-query string at the end of most URLs. (Look at "Filling in a form without spending
-a fortune" for an example with an URL-encoded query string.)
-
-You build a menu structure which is transformed to a function by the subroutine
-"translate"
-
-=for popUp2.pl begin
-
-    use PDF::Reuse;
-    use strict;
-     
-    prFile('doc/popUp2.pdf');
-    prCompress(1);
-    my $tree  = [ { text => 'General',
-                    kids => [  {text => 'Overview',
-                                 act  => 'get("http://127.0.0.1/gIndex.pdf");'},
-                                {text => 'Brokers',
-                                 act  => 'get("http://127.0.0.1/brokers.pdf");'},
-                                {text => 'Competitors',
-                                 act  => 'get("http://127.0.0.1/competitors.pdf");'}
-                            ] },
-                  { text => 'Status',
-                    kids => [  {text  => 'This year',
-                                act   => 'get("http://127.0.0.1/cgi-bin/saldo.pl");'},
-                               {text  => 'Monthly',
-                                act   => 'get("http://127.0.0.1/cgi-bin/monthBal.pl");'},
-                               {text  => 'Last Year',
-                                act   => 'get("http://127.0.0.1/cgi-bin/lYear.pl")'}
-                            ] },
-                  { text => 'Transactions',
-                    kids =>  [ {text => 'Purchased',
-                                act  => 'get("http://127.0.0.1/cgi-bin/purch.pl");' },
-                               {text => 'Ordered',
-                                act  => 'get("http://127.0.0.1/cgi-bin/ordered.pl");'} 
-                             ]}
-                ];
-        
-     my $str = translate('popUp1', $tree);
-
-     prJs($str);                        # include popUp1() as a string
-
-     prJs('Button.js');                 # Include code to define buttons
-        
-     $str = 'But(0, 450, 100, 100, 30,"popUp1();",
-            "Links to your other documents", "Other documents >");';          
-          
-     prInit($str);                      # runs the snippet just above
-                                        # when the document is opened
-        
-     prDoc('LetterB.pdf');
-     prEnd();
-
-     ###########################################################
-     # From here on, in this subroutine, the menu structure is 
-     # translated to a string
-     ###########################################################
-
-     sub translate
-     {   my $funcName = shift;
-         my $param    = shift;
-         my $i = 0;
-         my ($targetString, $nameString, $menuString);
-         
-         if (ref($param) eq 'HASH')
-         {   descend($param);
-         }
-         elsif (ref($param) eq 'ARRAY')
-         {   for (@{$param})
-             {  descend ($_);
-             }
-         }
-         chop($menuString);
-         chop($nameString);
-         chop($targetString);
-         
-         my $jsCode = "function $funcName()
-         {   var a = [$targetString];
-             var n = [$nameString];
-             var c = app.popUpMenu($menuString);
-             for (var i = 0; i < n.length; i++)
-             {   if (c == n[i])
-                 {   eval(a[i]);
-                     break;
-                 }
-             }
-          }";
-          $jsCode =~ s/^\s+//gm;            # remove leading spaces 
-          return $jsCode;
-     
-     
-          sub descend
-          {   my $struct = shift;
-              if (ref($struct) eq 'ARRAY')
-              {  for (@{$struct})
-                 {   descend ($_);
-                 }
-              }
-              elsif (ref($struct) eq 'HASH')
-              {   my %hash = %$struct;
-                  if (exists $hash{'kids'})
-                  {   $menuString .= "['$hash{'text'}',";
-                      descend ($hash{'kids'});
-                      chop($menuString);
-                      $menuString .= "],";
-                  }
-                  else
-                  {   $nameString   .= "'$hash{'text'}',";
-                      $targetString .= "'$hash{'act'}',";
-                      $menuString   .= "n[$i],";
-                      $i++;
-                  }
-              } 
-          }
-     }
-
-=for end
 
 =head1 AUTHOR
 
-Lars Lundberg : elkelund @ worldonline . se
+Lars Lundberg : larslund@cpan.org
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003 - 2004 Lars Lundberg, Solidez HB. All rights reserved.
+Copyright (C) 2003 - 2005 Lars Lundberg, Solidez HB. All rights reserved.
 This documentation is free; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
